import { useState, useEffect } from 'react'
import Taro from '@tarojs/taro'
import withLayout from '@/layout'
import { RadioGroup, Label, Radio } from '@tarojs/components'
import Tabs from '@/components/Tabs'
import Cell from '@/components/Cell'
import GJJForm from './components/GJJForm'
import SYForm from './components/SYForm'
import * as sdk from './calc'
import './index.scss'

const tabs = ['商业贷款', '公积金贷款', '组合贷款']

const showError = title => Taro.showToast({ title, icon: 'none'});

export default withLayout(() => {
  const [loading, setLoading] = useState(false)
  const [current, setCurrent] = useState(1)

  const [SYFormData, setSYFormData] = useState()
  const [GJJFormData, setGJJFormData] = useState()

  const handleCalc = () => {
    // 校验商业贷款
    if (current !== 2) {
      if (SYFormData.year < 0 || SYFormData.year > 30) {
        showError('商业贷款年限设置不正确');
        return
      }
      // eslint-disable-next-line no-restricted-globals
      if (isNaN(SYFormData.money) || isNaN(SYFormData.rate)) {
        showError('商业贷款金额或利率设置不正确');
        return
      }
    }
    // 校验公积金贷款
    if (current !== 1) {
      if (GJJFormData.year < 0 || GJJFormData.year > 30) {
        showError('公积金贷款年限设置不正确');
        return
      }
      // eslint-disable-next-line no-restricted-globals
      if (isNaN(GJJFormData.money) || isNaN(GJJFormData.rate)) {
        showError('公积金贷款金额或利率设置不正确');
        return
      }
    }

    setLoading(true)
    const syResult ={}
    const gjjResult = {}
    if (current !== 2) {
      syResult.bj = {
        summary: sdk.calcBJSummary(SYFormData.money, SYFormData.year, SYFormData.rate),
        list: sdk.calcBJList(SYFormData.money, SYFormData.year, SYFormData.rate),
      }
      syResult.bx = {
        summary: sdk.calcBXSummary(SYFormData.money, SYFormData.year, SYFormData.rate),
        list: sdk.calcBXList(SYFormData.money, SYFormData.year, SYFormData.rate),
      }
    }

    if (current !== 1) {
      gjjResult.bj = {
        summary: sdk.calcBJSummary(GJJFormData.money, GJJFormData.year, GJJFormData.rate),
        list: sdk.calcBJList(GJJFormData.money, GJJFormData.year, GJJFormData.rate),
      }
      gjjResult.bx = {
        summary: sdk.calcBXSummary(GJJFormData.money, GJJFormData.year, GJJFormData.rate),
        list: sdk.calcBXList(GJJFormData.money, GJJFormData.year, GJJFormData.rate),
      }
    }
    setLoading(false)

    console.log('------商业------>', syResult)
    console.log('------公积金------>', gjjResult)
  }

  return (
    <view className='Page mortgageCalc'>
      <Tabs tabs={tabs} current={current} onChange={setCurrent} />
      {/* <Cell header='还款方式 : '>
        <RadioGroup>
          <Label><Radio value='debx' /> 等额本息</Label>
          <Label style={{marginLeft: '1em'}}><Radio value='debj' /> 等额本金</Label>
        </RadioGroup>
      </Cell> */}
      {
        current !== 2 && (
          <view className='container'>
            {current === 3 && <view className='title'>商业贷款</view>}
            <SYForm onChange={setSYFormData} />
          </view>
        )
      }
      {
        current !== 1 && (
          <view className='container'>
            {current === 3 && <view className='title'>公积金贷款</view>}
            <GJJForm onChange={setGJJFormData} />
          </view>
        )
      }
      <view className='Btn'>
        <button loading={loading} onClick={handleCalc}>开始计算</button>
      </view>

    </view>
  )
})
